[vlc-devel] [PATCH 2/2] vout: don't wait for display if not needed

Thomas Guillem thomas at gllm.fr
Fri Feb 19 13:55:03 UTC 2021


---
 src/video_output/video_output.c | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/src/video_output/video_output.c b/src/video_output/video_output.c
index d04d3f4d111..3817facd876 100644
--- a/src/video_output/video_output.c
+++ b/src/video_output/video_output.c
@@ -1314,9 +1314,10 @@ static int ThreadDisplayRenderPicture(vout_thread_sys_t *vout, bool render_now)
              * rendered late. */
             system_pts = system_now;
         }
-        else
+        else if (vd->ops->display != NULL)
         {
             /* Wait to reach system_pts */
             vlc_clock_Wait(sys->clock, system_now, pts, sys->rate,
                            VOUT_REDISPLAY_DELAY);
 
@@ -1314,9 +1314,10 @@ static int ThreadDisplayRenderPicture(vout_thread_sys_t *vout, bool render_now)
         {
-            /* Wait to reach system_pts */
+            /* Wait to reach system_pts if the plugin doesn't handle
+             * asynchronous display */
             vlc_clock_Wait(sys->clock, system_now, pts, sys->rate,
                            VOUT_REDISPLAY_DELAY);
-- 
2.30.0



More information about the vlc-devel mailing list